'use strict';

Object.defineProperty(exports, '__esModule', { value: true });

// TODO: map the whole municipality's list
var municipalitiesLookup = {
    '01': 12,
    '02': 13,
    '03': 16,
    '04': 33,
    '05': 22,
    '06': 19,
    '07': 16,
    '08': 22,
    '09': 9,
    '10': 13,
    '11': 23,
    '12': 20,
    '13': 26,
    '14': 18,
};
/**
 * Verifies that given municipality code is valid foreign code
 *
 * @param  {string} code      A string representing municipality digits
 * @returns {boolean}         Foreign validity of the given municipality
 */
function isForeignCode(code) {
    return code.startsWith('9');
}
/**
 * Verifies that given municipality code is valid national code
 *
 * @param  {string} code      A string representing municipality digits
 * @returns {boolean}         National validity of the given municipality
 */
function isNationalCode(code) {
    if (!code.startsWith('0') && !code.startsWith('1'))
        return false;
    var department = code.substring(0, 2);
    var municipality = code.substring(2);
    return municipalitiesLookup[department] >= Number(municipality);
}
/**
 * Verifies that given municipality code is valid
 *
 * @param  {string} code      A string representing municipality digits
 * @returns {boolean}         Validity of the given municipality
 */
function isMunicipalityCode(code) {
    return code.length === 4 && (isForeignCode(code) || isNationalCode(code));
}

/**
 * Calculates full year for a given two-digit format year
 *
 * @param  {string} year      A string representing two-digit format year
 * @returns {string}          Full year
 */
function getFullYear(year) {
    return Number(year) >=
        Number(new Date().getFullYear().toString().substr(-2)) + 1
        ? '19'.concat(year)
        : '20'.concat(year);
}
/**
 * Verifies that given NIT format birthdate is valid
 *
 * @param  {string} str       A string representing NIT format birthdate
 * @returns {boolean}         Validity of the given birthdate
 */
function isDate(str) {
    var year = getFullYear(str.substring(4));
    var month = str.substring(2, 4);
    var day = str.substring(0, 2);
    var date = new Date(year + "/" + month + "/" + day);
    return date && Number(date.getMonth()) + 1 === Number(month);
}

var duiRegExp = /(^\d{8})-(\d$)/;
var nitRegExp = /(^\d{4})-(\d{6})-(\d{3})-(\d$)/;
/**
 * Verifies that given DUI format is valid
 *
 * @param  {string} str       A string representing DUI digits (with hyphen)
 * @returns {boolean}         Validity of the given DUI
 */
function isDUI(str) {
    if (!duiRegExp.test(str))
        return false;
    var sum = 0;
    var _a = str.split('-'), digits = _a[0], verifier = _a[1];
    for (var i = 0; i < digits.length; i++) {
        sum += Number(digits[i]) * (digits.length + 1 - i);
    }
    return Number(verifier) === (10 - (sum % 10)) % 10 && sum > 0;
}
/**
 * Calculates verification value for a given old format NIT
 *
 * @param  {string} digits    A string representing NIT digits (without hyphen and verifier)
 * @returns {number}          Verification value for a given old format NIT
 */
function calculateNitVerificationOldFormat(digits) {
    var sum = 0;
    for (var i = 0; i < digits.length; i++) {
        sum += Number(digits[i]) * (digits.length + 1 - i);
    }
    sum %= 11;
    return sum;
}
/**
 * Calculates verification value for a given NIT
 *
 * @param  {string} digits    A string representing NIT digits (without hyphen and verifier)
 * @returns {number}          Verification value for a given NIT
 */
function calculateNitVerification(digits) {
    var sum = 0;
    for (var i = 0; i < digits.length; i++) {
        sum +=
            Number(digits[i]) * (3 + 6 * Math.floor(Math.abs((i + 5) / 6)) - (i + 1));
    }
    sum %= 11;
    return sum > 1 ? 11 - sum : 0;
}
/**
 * Verifies that given NIT format is valid
 *
 * @param  {string} str       A string representing NIT digits (with hyphen)
 * @returns {boolean}         Validity of the given NIT
 */
function isNIT(str) {
    if (!nitRegExp.test(str))
        return false;
    var _a = str.split('-'), municipality = _a[0], birthdate = _a[1], correlative = _a[2], verifier = _a[3];
    if (!isMunicipalityCode(municipality) || !isDate(birthdate))
        return false;
    var digits = municipality + birthdate + correlative;
    var sum = correlative.startsWith('0')
        ? calculateNitVerificationOldFormat(digits)
        : calculateNitVerification(digits);
    return Number(verifier) === sum;
}

/**
 * Beginning with 6 or 7 follow by three digits, then a dash and ends with four digits only
 */
var mobilePhoneRegExP = /^[67]\d{3}-\d{4}$/;
/**
 * Beginning with 2 follow by three digits, then a dash and ends with four digits only
 */
var residentialPhoneRegExP = /^2\d{3}-\d{4}$/;
/**
 * Verifies that given string number is a mobile number
 *
 * @param {string} phone A string phone number with a dash included
 * @returns {boolean} Is a valid mobile phone number
 */
function isMobilePhoneNumber(phone) {
    if (typeof phone !== 'string')
        return false;
    return mobilePhoneRegExP.test(phone);
}
/**
 * Verifies that given string number is a residential number
 *
 * @param {string} phone A string phone number with a dash included
 * @returns {boolean} Is a valid residential phone number
 */
function isResidentialPhoneNumber(phone) {
    if (typeof phone !== 'string')
        return false;
    return residentialPhoneRegExP.test(phone);
}
/**
 * Verifies that given string number is a phone number
 *
 * @param {string} phone A string phone number with a dash included
 * @returns {boolean} Is a valid phone number
 */
function isPhoneNumber(phone) {
    return isMobilePhoneNumber(phone) || isResidentialPhoneNumber(phone);
}

exports.isDUI = isDUI;
exports.isMobilePhoneNumber = isMobilePhoneNumber;
exports.isMunicipalityCode = isMunicipalityCode;
exports.isNIT = isNIT;
exports.isPhoneNumber = isPhoneNumber;
exports.isResidentialPhoneNumber = isResidentialPhoneNumber;
//# sourceMappingURL=index.js.map
